# Training
- train.py allows training of all five models
- run_models.sh trains all models, with train.py, at 4 throughout 7 epochs, generating all necessary meta data for each of the model/ epoch combinations
- meta_data.py collects all the meta_data generated by run_models, calculating the 5-fold cross-validation for each of the model/ epoch combinations, and saving it to the meta_data directory
- meta_data is a directory that contains json files with 5-fold cross-validations for each of the five models
- test_dataset.py allows loading the training dataset for testing purposes
